[PATCH tip/core/rcu 19/19] locking/locktorture: Convert to SPDX license identifier

From: Paul E. McKenney
Date: Wed Feb 06 2019 - 08:20:48 EST


Replace the license boiler plate with a SPDX license identifier.
While in the area, update an email address.

Signed-off-by: Paul E. McKenney <paulmck@xxxxxxxxxxxxx>
---
kernel/locking/locktorture.c | 19 +++----------------
1 file changed, 3 insertions(+), 16 deletions(-)

diff --git a/kernel/locking/locktorture.c b/kernel/locking/locktorture.c
index 7d0b0ed74404..d163c5b75d72 100644
--- a/kernel/locking/locktorture.c
+++ b/kernel/locking/locktorture.c
@@ -1,23 +1,10 @@
+// SPDX-License-Identifier: GPL-2.0+
/*
* Module-based torture test facility for locking
*
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, you can access it online at
- * http://www.gnu.org/licenses/gpl-2.0.html.
- *
* Copyright (C) IBM Corporation, 2014
*
* Authors: Paul E. McKenney <paulmck@xxxxxxxxxx>
* Davidlohr Bueso <dave@xxxxxxxxxxxx>
* Based on kernel/rcu/torture.c.
*/
@@ -45,7 +32,7 @@
#include <linux/torture.h>

MODULE_LICENSE("GPL");
-MODULE_AUTHOR("Paul E. McKenney <paulmck@xxxxxxxxxx>");
+MODULE_AUTHOR("Paul E. McKenney <paulmck@xxxxxxxxxxxxx>");

torture_param(int, nwriters_stress, -1,
"Number of write-locking stress-test threads");
@@ -1,23 +1,10 @@
* Copyright (C) IBM Corporation, 2014
*
- * Authors: Paul E. McKenney <paulmck@xxxxxxxxxx>
+ * Authors: Paul E. McKenney <paulmck@xxxxxxxxxxxxx>
* Davidlohr Bueso <dave@xxxxxxxxxxxx>
* Based on kernel/rcu/torture.c.
--
2.17.1